MAXIMUM_CLOCK_SKEW = 300

URL_ENCODED = "application/x-www-form-urlencoded"
JSON_ENCODED = "application/json"
JOSE_ENCODED = "application/jose"

DEFAULT_POST_CONTENT_TYPE = URL_ENCODED
